@@ -4,7 +4,8 @@ require 5.005_62;
 use strict;
 use warnings;
 use Carp;
-
+use Tie::Array;
+our @ISA = ('Tie::Array');
 require Exporter;
 
 our $VERSION = '0.20';
@@ -52,12 +53,20 @@ sub TIEARRAY {
     return bless [($fh,$seqformat,$filename)], $class;
 } # create the tied array
 
+# maybe I should just try to write a temp file
+# in table format first?
+my $last_call = ""; # kludge to reset position
 sub FETCH {
     my $self = shift;
     confess "I ($self) am not a class method!" unless ref $self;
     my $fh = $$self[0];
     my $format = $$self[1];
     my $seqrec = "";
+    my $call = join(":",((caller(1))[3,2]));
+    if ($last_call ne $call) {
+        $last_call = $call;
+        seek $fh,0,0;
+    } # called from different routine - reset
     
     if ($format =~ /TBL|RAW|CDNA/) {
         $seqrec = <$fh>;
@@ -98,6 +107,47 @@ sub FETCH {
     } # get next ig record
 } # read data
 
+sub FETCHSIZE {
+    my $self = shift;
+    confess "I ($self) am not a class method!" unless ref $self;
+    my $fh = $$self[0];
+    my $format = $$self[1];
+    
+    if ($format =~ /TBL|RAW|CDNA/) {
+        my $pos = tell $fh;
+        seek $fh,0,0;
+        my $c = 0;
+        while (<$fh>) { $c++ }
+        seek $fh,$pos,0;
+        return $c;
+    } # single line records
+    elsif ($format eq "FA") {
+        my $pos = tell $fh;
+        seek $fh,0,0;
+        my $c = 0;
+        while (my $l = <$fh>) { $c++ if $l =~ /^>/ } # will break on concurrent > lines
+        seek $fh,$pos,0;
+        return $c;
+    } # elsif fasta
+    elsif ($format eq "IG") {
+        my $pos = tell $fh;
+        seek $fh,0,0;
+        my $c = my $on = 0;
+        while (<$fh>) {
+            if (/^\s*;/) {
+                $on = 1;
+            } # comment/seperator lines found
+            elsif ($on) {
+                $c++;
+                $on = 0;
+            } #  should be id line after comment/seperator lines
+        } # while counting records
+        seek $fh,$pos,0;
+        return $c;
+    } # elsif ig
+} # FETCHSIZE
+
+
 sub DESTROY {
     my $self = shift;
     confess "I ($self) am not a class method!" unless ref $self;
